@@ -195,7 +195,7 @@ QHash<PimCommon::ActionType::Type, QList<QAction *> > PluginInterface::actionsTy
             }
             if (interface->plugin()->hasPopupMenuSupport()) {
                 type = PimCommon::ActionType::PopupMenu;
-                QList<QAction *> lst = listType.value(type);
+                lst = listType.value(type);
                 if (!lst.isEmpty()) {
                     QAction *act = new QAction(this);
                     act->setSeparator(true);
@@ -207,7 +207,7 @@ QHash<PimCommon::ActionType::Type, QList<QAction *> > PluginInterface::actionsTy
             }
             if (interface->plugin()->hasToolBarSupport()) {
                 type = PimCommon::ActionType::ToolBar;
-                QList<QAction *> lst = listType.value(type);
+                lst = listType.value(type);
                 if (!lst.isEmpty()) {
                     QAction *act = new QAction(this);
                     act->setSeparator(true);
